@@ -9,11 +9,6 @@
 // app includes
 #include "basictypes.h"
 
-// kde includes
-#if QT_VERSION < 0x050000
-#include <kicon.h>
-#endif
-
 // qt includes
 #include <QCursor>
 #include <QPixmap>
