@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2004-2021 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2004-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // own header
@@ -43,6 +43,8 @@ const int ClassifierWidget::SOCKET_INCREMENT = 10;
  */
 ClassifierWidget::ClassifierWidget(UMLScene * scene, UMLClassifier *umlc)
   : UMLWidget(scene, WidgetBase::wt_Class, umlc),
+    m_attributeSignature(Uml::SignatureType::NoSigNoVis),
+    m_operationSignature(Uml::SignatureType::NoSigNoVis),
     m_pAssocWidget(nullptr),
     m_pInterfaceName(nullptr)
 {
@@ -349,7 +351,8 @@ void ClassifierWidget::toggleVisualProperty(VisualProperty property)
         oppositeStatus = !visualProperty(property);
     }
 
-    DEBUG(DBG_SRC) << "VisualProperty: " << property << " to opposite status " << oppositeStatus;
+    logDebug2("ClassifierWidget::toggleVisualProperty property: %1 to opposite status: %2",
+              property, oppositeStatus);
     setVisualProperty(property, oppositeStatus);
 }
 
@@ -579,7 +582,7 @@ QSizeF ClassifierWidget::calculateSize(bool withExtensions /* = true */) const
 
     QString displayedName;
     if (m_umlObject && m_umlObject->isUMLInstance())
-        displayedName = m_umlObject->name() + QLatin1String(" : ") + name;
+        displayedName = m_umlObject->name() + QStringLiteral(" : ") + name;
     else
         displayedName = name;
 
@@ -668,6 +671,9 @@ QSizeF ClassifierWidget::calculateSize(bool withExtensions /* = true */) const
     if (DiagramProxyWidget::linkedDiagram() || DiagramProxyWidget::diagramLink() != Uml::ID::None)
         width += 2 * DiagramProxyWidget::iconRect().width();
 
+    logDebug5("ClassifierWidget::calculateSize(%1) : "
+              "rectWidth %2, rectHeight %3 ; calcWidth %4, calcHeight %5",
+              name, this->width(), this->height(), width, height);
     return QSizeF(width, height);
 }
 
@@ -733,7 +739,8 @@ int ClassifierWidget::displayedOperations() const
 void ClassifierWidget::setClassAssociationWidget(AssociationWidget *assocwidget)
 {
     if (!classifier()) {
-        uError() << "Class association cannot be applied to non classifier";
+        logError0("ClassifierWidget::setClassAssociationWidget: "
+                  "Class association cannot be applied to non classifier");
         return;
     }
     m_pAssocWidget = assocwidget;
@@ -773,7 +780,7 @@ void ClassifierWidget::paint(QPainter *painter, const QStyleOptionGraphicsItem *
         if (m_umlObject && m_umlObject->isUMLInstance()) {
             umlc = m_umlObject->asUMLInstance()->classifier();
         } else {
-            uError() << "ClassifierWidget::paint internal error - classifier() returns NULL";
+            logError0("ClassifierWidget::paint internal error - classifier() returns null");
             return;
         }
     }
@@ -858,7 +865,7 @@ void ClassifierWidget::paint(QPainter *painter, const QStyleOptionGraphicsItem *
     if (!m_umlObject) {
         displayedName = m_Text;
     } else if (m_umlObject->isUMLInstance()) {
-        displayedName = m_umlObject->name() + QLatin1String(" : ");
+        displayedName = m_umlObject->name() + QStringLiteral(" : ");
         if (umlc) {
             if (visualProperty(ShowPackage))
                 displayedName.append(umlc->fullyQualifiedName());
@@ -1005,8 +1012,8 @@ void ClassifierWidget::drawAsCircle(QPainter *painter, const QStyleOptionGraphic
         const qreal cY = center.y();
 
         foreach (AssociationWidget *aw, requiredAssocs) {
-            AssociationLine *assocLine = aw->associationLine();
-            const QPointF p(assocLine->endPoint());
+            const AssociationLine& assocLine = aw->associationLine();
+            const QPointF p(assocLine.endPoint());
             const qreal tolerance = 18.0;
             bool drawArc = true;
             qreal midAngle;
@@ -1038,8 +1045,8 @@ void ClassifierWidget::drawAsCircle(QPainter *painter, const QStyleOptionGraphic
                 //          << ", midAngle: " << midAngle << ", angleSpan: " << angleSpan;
                 painter->drawArc(requireArc, 16 * (midAngle - angleSpan/2), 16 * angleSpan);
             } else {
-                uError() << "socket: assocLine endPoint " << p
-                         << " too close to own center" << center;
+                logError4("ClassifierWidget::drawAsCircle socket: assocLine endPoint (%1,%2) is "
+                          "too close to own center (%3,%4)", p.x(), p.y(), cX, cY);
             }
         }
     }
@@ -1070,7 +1077,7 @@ void ClassifierWidget::drawAsPackage(QPainter *painter, const QStyleOptionGraphi
     const int fontHeight  = fm.lineSpacing();
 
     painter->drawRect(0, 0, 50, fontHeight);
-    if (m_umlObject->stereotype() == QLatin1String("subsystem")) {
+    if (m_umlObject->stereotype() == QStringLiteral("subsystem")) {
         const int fHalf = fontHeight / 2;
         const int symY = fHalf;
         const int symX = 38;
@@ -1125,7 +1132,7 @@ QSize ClassifierWidget::calculateAsPackageSize() const
  * Auxiliary method for draw() of child classes:
  * Draw the attributes or operations.
  *
- * @param p          QPainter to paint to.
+ * @param painter    QPainter to paint to.
  * @param ot         Object type to draw, either ot_Attribute or ot_Operation.
  * @param sigType    Governs details of the member display.
  * @param x          X coordinate at which to draw the texts.
@@ -1164,8 +1171,8 @@ void ClassifierWidget::drawMembers(QPainter * painter,
         if (drawInstanceAttributes) {
             UMLInstanceAttribute *iatt = ialist.at(i)->asUMLInstanceAttribute();
             if (!iatt) {
-                uDebug() << "ClassifierWidget::drawMembers(" << obj->name()
-                         << ") : skipping non InstanceAttribute subordinate";
+                logDebug1("ClassifierWidget::drawMembers(%1) : skipping non InstanceAttribute subordinate",
+                          obj->name());
                 continue;
             }
             /* CHECK: Do we want visibility indication on instance attributes?
@@ -1202,7 +1209,7 @@ UMLWidget* ClassifierWidget::onWidget(const QPointF &p)
     if (UMLWidget::onWidget(p) != nullptr)
         return this;
     if (getDrawAsCircle() && m_pInterfaceName) {
-        uDebug() << "floatingtext: " << m_pInterfaceName->text();
+        logDebug1("ClassifierWidget::onWidget: floatingtext %1", m_pInterfaceName->text());
         return m_pInterfaceName->onWidget(p);
     }
     return nullptr;
@@ -1340,9 +1347,9 @@ void ClassifierWidget::changeToPackage()
 /**
  * Loads the "classwidget" or "interfacewidget" XML element.
  */
-bool ClassifierWidget::loadFromXMI1(QDomElement & qElement)
+bool ClassifierWidget::loadFromXMI(QDomElement & qElement)
 {
-    if (!UMLWidget::loadFromXMI1(qElement)) {
+    if (!UMLWidget::loadFromXMI(qElement)) {
         return false;
     }
     if (DiagramProxyWidget::linkedDiagram())
@@ -1353,15 +1360,15 @@ bool ClassifierWidget::loadFromXMI1(QDomElement & qElement)
         loadShowAttributes = false;
     }
     if (loadShowAttributes) {
-        QString showatts = qElement.attribute(QLatin1String("showattributes"), QLatin1String("0"));
-        QString showops = qElement.attribute(QLatin1String("showoperations"), QLatin1String("1"));
-        QString showpubliconly = qElement.attribute(QLatin1String("showpubliconly"), QLatin1String("0"));
-        QString showattsigs = qElement.attribute(QLatin1String("showattsigs"), QLatin1String("600"));
-        QString showopsigs = qElement.attribute(QLatin1String("showopsigs"), QLatin1String("600"));
-        QString showpackage = qElement.attribute(QLatin1String("showpackage"), QLatin1String("0"));
-        QString showscope = qElement.attribute(QLatin1String("showscope"), QLatin1String("0"));
-        QString drawascircle = qElement.attribute(QLatin1String("drawascircle"), QLatin1String("0"));
-        QString showstereotype = qElement.attribute(QLatin1String("showstereotype"), QLatin1String("1"));
+        QString showatts = qElement.attribute(QStringLiteral("showattributes"), QStringLiteral("0"));
+        QString showops = qElement.attribute(QStringLiteral("showoperations"), QStringLiteral("1"));
+        QString showpubliconly = qElement.attribute(QStringLiteral("showpubliconly"), QStringLiteral("0"));
+        QString showattsigs = qElement.attribute(QStringLiteral("showattsigs"), QStringLiteral("600"));
+        QString showopsigs = qElement.attribute(QStringLiteral("showopsigs"), QStringLiteral("600"));
+        QString showpackage = qElement.attribute(QStringLiteral("showpackage"), QStringLiteral("0"));
+        QString showscope = qElement.attribute(QStringLiteral("showscope"), QStringLiteral("0"));
+        QString drawascircle = qElement.attribute(QStringLiteral("drawascircle"), QStringLiteral("0"));
+        QString showstereotype = qElement.attribute(QStringLiteral("showstereotype"), QStringLiteral("1"));
         setVisualPropertyCmd(ShowAttributes, (bool)showatts.toInt());
         setVisualPropertyCmd(ShowOperations, (bool)showops.toInt());
         setVisualPropertyCmd(ShowPublicOnly, (bool)showpubliconly.toInt());
@@ -1374,7 +1381,7 @@ bool ClassifierWidget::loadFromXMI1(QDomElement & qElement)
     }
 
 #ifdef ENABLE_WIDGET_SHOW_DOC
-    QString showDocumentation = qElement.attribute(QLatin1String("showdocumentation"), QLatin1String("0"));
+    QString showDocumentation = qElement.attribute(QStringLiteral("showdocumentation"), QStringLiteral("0"));
     setVisualPropertyCmd(ShowDocumentation, (bool)showDocumentation.toInt());
 #endif
 
@@ -1386,14 +1393,14 @@ bool ClassifierWidget::loadFromXMI1(QDomElement & qElement)
     QDomElement element = node.toElement();
     if (!element.isNull()) {
         QString tag = element.tagName();
-        if (tag == QLatin1String("floatingtext")) {
+        if (tag == QStringLiteral("floatingtext")) {
             if (m_pInterfaceName == nullptr) {
                 m_pInterfaceName = new FloatingTextWidget(m_scene,
                                                           Uml::TextRole::Floating,
                                                           name(), Uml::ID::Reserved);
                 m_pInterfaceName->setParentItem(this);
             }
-            if (!m_pInterfaceName->loadFromXMI1(element)) {
+            if (!m_pInterfaceName->loadFromXMI(element)) {
                 // Most likely cause: The FloatingTextWidget is empty.
                 delete m_pInterfaceName;
                 m_pInterfaceName = nullptr;
@@ -1402,7 +1409,7 @@ bool ClassifierWidget::loadFromXMI1(QDomElement & qElement)
                 m_pInterfaceName->update();
             }
         } else {
-            uError() << "unknown tag " << tag;
+            logError1("ClassifierWidget::loadFromXMI: unknown tag %1", tag);
         }
     }
 
@@ -1412,42 +1419,41 @@ bool ClassifierWidget::loadFromXMI1(QDomElement & qElement)
 /**
  * Creates the "classwidget" or "interfacewidget" XML element.
  */
-void ClassifierWidget::saveToXMI1(QXmlStreamWriter& writer)
+void ClassifierWidget::saveToXMI(QXmlStreamWriter& writer)
 {
     bool saveShowAttributes = true;
     UMLClassifier *umlc = classifier();
     QString tag;
     if (umlObject()->baseType() == UMLObject::ot_Package) {
-        tag = QLatin1String("packagewidget");
+        tag = QStringLiteral("packagewidget");
         saveShowAttributes = false;
     } else if (umlObject()->baseType() == UMLObject::ot_Instance) {
-        tag = QLatin1String("instancewidget");
+        tag = QStringLiteral("instancewidget");
         saveShowAttributes = false;
     } else if (umlc && umlc->isInterface()) {
-        tag = QLatin1String("interfacewidget");
+        tag = QStringLiteral("interfacewidget");
     } else {
-        tag = QLatin1String("classwidget");
+        tag = QStringLiteral("classwidget");
     }
     writer.writeStartElement(tag);
 
-    UMLWidget::saveToXMI1(writer);
+    UMLWidget::saveToXMI(writer);
     if (saveShowAttributes) {
-        writer.writeAttribute(QLatin1String("showoperations"), QString::number(visualProperty(ShowOperations)));
-        writer.writeAttribute(QLatin1String("showpubliconly"), QString::number(visualProperty(ShowPublicOnly)));
-        writer.writeAttribute(QLatin1String("showopsigs"),     QString::number(m_operationSignature));
-        writer.writeAttribute(QLatin1String("showpackage"),    QString::number(visualProperty(ShowPackage)));
-        writer.writeAttribute(QLatin1String("showscope"),      QString::number(visualProperty(ShowVisibility)));
-        writer.writeAttribute(QLatin1String("showattributes"), QString::number(visualProperty(ShowAttributes)));
-        writer.writeAttribute(QLatin1String("showattsigs"),    QString::number(m_attributeSignature));
-        writer.writeAttribute(QLatin1String("showstereotype"), QString::number(m_showStereotype));
+        writer.writeAttribute(QStringLiteral("showoperations"), QString::number(visualProperty(ShowOperations)));
+        writer.writeAttribute(QStringLiteral("showpubliconly"), QString::number(visualProperty(ShowPublicOnly)));
+        writer.writeAttribute(QStringLiteral("showopsigs"),     QString::number(m_operationSignature));
+        writer.writeAttribute(QStringLiteral("showpackage"),    QString::number(visualProperty(ShowPackage)));
+        writer.writeAttribute(QStringLiteral("showscope"),      QString::number(visualProperty(ShowVisibility)));
+        writer.writeAttribute(QStringLiteral("showattributes"), QString::number(visualProperty(ShowAttributes)));
+        writer.writeAttribute(QStringLiteral("showattsigs"),    QString::number(m_attributeSignature));
     }
 #ifdef ENABLE_WIDGET_SHOW_DOC
-    writer.writeAttribute(QLatin1String("showdocumentation"), QString::number(visualProperty(ShowDocumentation)));
+    writer.writeAttribute(QStringLiteral("showdocumentation"), QString::number(visualProperty(ShowDocumentation)));
 #endif
     if (umlc && (umlc->isInterface() || umlc->isAbstract())) {
-        writer.writeAttribute(QLatin1String("drawascircle"), QString::number(visualProperty(DrawAsCircle)));
+        writer.writeAttribute(QStringLiteral("drawascircle"), QString::number(visualProperty(DrawAsCircle)));
         if (visualProperty(DrawAsCircle) && m_pInterfaceName) {
-            m_pInterfaceName->saveToXMI1(writer);
+            m_pInterfaceName->saveToXMI(writer);
         }
     }
     writer.writeEndElement();
@@ -1462,7 +1468,7 @@ void ClassifierWidget::saveToXMI1(QXmlStreamWriter& writer)
 void ClassifierWidget::slotMenuSelection(QAction* action)
 {
     ListPopupMenu::MenuType sel = ListPopupMenu::typeFromAction(action);
-    uDebug() << "ClassifierWidget::slotMenuSelection sel = " << sel;
+    logDebug1("ClassifierWidget::slotMenuSelection sel = %1", sel);
     switch (sel) {
     case ListPopupMenu::mt_Attribute:
     case ListPopupMenu::mt_Operation:
@@ -1471,7 +1477,8 @@ void ClassifierWidget::slotMenuSelection(QAction* action)
             UMLObject::ObjectType ot = ListPopupMenu::convert_MT_OT(sel);
             UMLClassifier *umlc = classifier();
             if (!umlc) {
-                uError() << "Internal error - classifier() returns NULL";
+                logError1("ClassifierWidget::slotMenuSelection(%1) internal error - classifier() returns null",
+                          sel);
                 return;
             }
             if (Object_Factory::createChildObject(umlc, ot)) {
@@ -1490,7 +1497,8 @@ void ClassifierWidget::slotMenuSelection(QAction* action)
             UMLObject::ObjectType ot = ListPopupMenu::convert_MT_OT(sel);
             UMLClassifier *umlc = classifier();
             if (!umlc) {
-                uError() << "Internal error - classifier() returns NULL";
+                logError1("ClassifierWidget::slotMenuSelection(%1) internal error - classifier() returns null",
+                          sel);
                 return;
             }
             umlScene()->setCreateObject(true);
